The gedit widget has the following methods: The svalue method retrieves the value. If a function is
given to the argument coerce.with it is applied before
the value is returned. This can be used to coerce the text
value (always of class character) to a numeric, or to a date,
or to be quoted, ...
The svalue<- method is used to set the value.
The "[" and "[<-" methods refer to the widgets
"type-ahead" values. A familiar usage is when a url is typed
into a web browser, matches appear from a users history that
could possibly complete the typed url.
The gtext widget has the following methods.
The svalue method returns the text held in the
buffer. If drop=TRUE, then only the text in the buffer
selected by the mouse is returned.
The svalue<- method replaces the text in the buffer
with the new text.
New text is added with the add method. The basic usage
is add(obj,text) where "text" could be a single line or
a vector of text, or a gwidget (although some, like gedit, are kind of
flaky). Extra arguments include do.newline a
logical indicating if a new line after the last line should be
added (default is TRUE); font.attr to specify
any font attributes; where indicating where to add the
text (either end or beginning).
The font can be changed. The font.attr argument to the
constructon and to add specifies fonts using a
namedcharacter vector. For instance
c(style="normal", weights="bold",sizes="medium").
The command obj[['tags']] will produce a list
containing all the available attributes.
The font<- method is used to change the font of the
currently selected text. It too takes a named character vector
specifying the font attributes.
The dispose method clears the text in the buffer.